pub struct EmbassyClock { /* private fields */ }Expand description
A clock with at maximum microsecond precision.
The actual precision depends on the tick rate configured for the underlying embassy_time clock.
To construct a clock, use EmbassyClock::default().
The clock is “started” when it is constructed.
Limitations
The clock represents up to ~584542 years worth of time, after which it will roll over.